@@ -1,5 +1,5 @@
 /* Decimal floating point support.
-   Copyright (C) 2005, 2006, 2007, 2008, 2009 Free Software
+   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010 Free Software
    Foundation, Inc.
 
 This file is part of GCC.
@@ -23,8 +23,6 @@ along with GCC; see the file COPYING3.  If not see
 #include "coretypes.h"
 #include "tm.h"
 #include "tree.h"
-#include "toplev.h"
-#include "real.h"
 #include "tm_p.h"
 #include "dfp.h"
 
